capture log close
set more off

* Insert your path here - set working directory
cd "C:\..."
use "cps_data.dta", clear

drop if year <= 1985
drop if country_polity == 305 | country_polity == 375 | country_polity == 380 

by country, sort: egen ranking = mean(reasoned_opinions)

* Graph 1:

graph box reasoned_opinions, medtype(cline) over(country_short, sort(ranking)) ytitle("Annual Violations (Reasoned Opinions)") /*
   */ medline(lcolor(black)) scheme(sj) 
graph save "cps_graph1.gph"

use "cps_data.dta", clear

mcenter  gdp ssi gdppc constraints rule_of_law eu_support
gen C_efficiency = efficiency - 2

gen C_ssiefficiency = C_ssi * C_efficiency 
gen C_rule_of_lawefficiency = C_rule_of_law * C_efficiency 
gen C_eu_supportefficiency = C_eu_support * C_efficiency 
gen C_ssirule_of_law = C_ssi * C_rule_of_law 
gen C_ssieu_support = C_ssi * C_eu_support 

tab year, gen(y_)

* Table 1, Model 1:

reg  dv_rs169 C_gdp C_ssi C_gdppc C_efficiency C_constraints C_rule_of_law C_eu_support y_2-y_22, cluster(country_polity)
outreg2 using "cps_table1.txt", auto(3) less(1) bdec(4) adjr2 

* Table 1, Model 2:

reg  dv_rs169 C_ssi C_efficiency C_ssiefficiency C_gdp C_gdppc C_constraints C_rule_of_law C_eu_support y_2-y_22, cluster(country_polity)
outreg2 using "cps_table1.txt", auto(3) less(1) bdec(4) adjr2 append

gen fixmed = C_ssi * 0
gen yhatmed = _b[_cons] + _b[C_ssi] * C_ssi + _b[C_efficiency]* 0 + _b[C_ssiefficiency] * fixmed
gen fixmin = C_ssi * -1
gen yhatmin  = _b[_cons] + _b[C_ssi] * C_ssi + _b[C_efficiency]*-1 + _b[C_ssiefficiency] * fixmin 
sum ssi
gen yhatmin2 = yhatmin if ssi == r(min)
replace yhatmin2 = yhatmin if ssi == r(max)
gen fixmax = C_ssi * 1
gen yhatmax  = _b[_cons] + _b[C_ssi] * C_ssi + _b[C_efficiency]* 1 + _b[C_ssiefficiency] * fixmax
sum ssi
gen yhatmax2 = yhatmax if ssi == r(min)
replace yhatmax2 = yhatmax if ssi == r(max)

line yhatmin2 ssi, lpattern(-) || line yhatmed ssi || line yhatmax2 ssi, lpattern(_) subtitle("(a) Conditional Slopes") scheme(sj) /*
   */ xtitle("Shapley Shubik Index") xlabel(0 "0" 5 ".05" 10 ".1" 15 ".15" 20 ".2") ytitle("Reasoned Opinions per legal act (in %)") /*
   */ legend(size(3) col(1) order(1 2 3) label(1 "Efficiency = low") label(2 "Efficiency = medium") label(3 "Efficiency = high"))
graph save "cps_graph2a.gph"

generate MV=((_n-1)/90)
replace  MV=. if _n>300
matrix b=e(b) 
matrix V=e(V)
scalar b1=b[1,1]
scalar b2=b[1,2]
scalar b3=b[1,3]
scalar varb1=V[1,1]
scalar varb2=V[2,2]
scalar varb3=V[3,3]
scalar covb1b3=V[1,3]
scalar covb2b3=V[2,3]
scalar list b1 b2 b3 varb1 varb2 varb3 covb1b3 covb2b3
gen conb=b1+b3*MV if _n<300
gen conse=sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n<300
gen a=1.645*conse
gen upper=conb+a
gen lower=conb-a

line conb MV || line upper  MV, clpattern(dash) || line lower  MV, clpattern(dash) legend(size(3) col(1) order(2) /*
   */ label(2 "90% confidence intervals")) xtitle("Efficiency") /*
   */ xlabel(0 "0" 0.5 " " 1 "1" 1.5 " " 2 "2" 2.5 " " 3 "3" 3.5 " ") /*
   */ ytitle("Marginal effect of Shapley Shubik Index") subtitle("(b) Marginal Effect") scheme(sj)
graph save "cps_graph2b.gph"

* Graph 2:

graph combine "cps_graph2a.gph" "cps_graph2b.gph", scheme(sj) saving("cps_graph2.gph") 

* Table 1, Model 3:

reg  dv_rs169 C_gdp C_ssi C_gdppc C_efficiency C_constraints C_rule_of_law C_eu_support C_rule_of_lawefficiency C_eu_supportefficiency y_2-y_22, cluster(country_polity)
outreg2 using "cps_table1.txt", auto(3) less(1) bdec(4) adjr2 append

* Table 1, Model 4:

reg  dv_rs169 C_gdp C_ssi C_gdppc C_efficiency C_constraints C_rule_of_law C_eu_support C_ssirule_of_law C_ssieu_support y_2-y_22, cluster(country_polity)
outreg2 using "cps_table1.txt", auto(3) less(1) bdec(4) adjr2 append

* Table 1, Model 5:

reg  dv_cs169 C_gdp C_ssi C_gdppc C_efficiency C_constraints C_rule_of_law C_eu_support C_ssiefficiency y_2-y_22, cluster(country_polity)
outreg2 using "cps_table1.txt", auto(3) less(1) bdec(4) adjr2 append

exit, clear
 
